@@ -41,19 +41,9 @@ from abc import ABCMeta, abstractmethod, abstractproperty
 from sympy import I, pi, sqrt, exp, sin, cos, log, symbols
 from numpy import zeros as np_zeros
 import qutip
-from qnet.algebra.abstract_algebra import (
-    AlgebraException, AlgebraError, Expression, Operation, assoc,
-    check_signature, check_signature_assoc,
-    singleton, preprocess_create_with, filter_neutral,
-    match_replace_binary, prod, match_replace, substitute,
-    CannotSimplify, wc)
-from qnet.algebra.hilbert_space_algebra import HilbertSpace, FullSpace, TrivialSpace, local_space
-from qnet.algebra.operator_algebra import (
-    Operator, OperatorSymbol, ScalarTimesOperator, IdentityOperator, adjoint, ImAdjoint, Im, Matrix, block_matrix, sympyOne, zerosm,
-    vstackm, Destroy, Create, identifier_to_tex, tex, identity_matrix, permutation_matrix, space, get_coeffs, IdentityMatrix)
-from qnet.algebra.permutations import check_permutation, BadPermutationError, permutation_to_block_permutations, \
-    invert_permutation, block_perm_and_perms_within_blocks, full_block_perm, concatenate_permutations
 
+from qnet.algebra.operator_algebra import *
+from qnet.algebra.permutations import *
 
 class CannotConvertToSLH(AlgebraException):
     """
